pub struct TCReplica { /* private fields */ }Expand description
***** TCReplica *****
A replica represents an instance of a user’s task data, providing an easy interface for querying and modifying that data.
Error Handling
When a tc_replica_.. function that returns a TCResult returns TC_RESULT_ERROR, then
tc_replica_error will return the error message.
Safety
The *TCReplica returned from tc_replica_new… functions is owned by the caller and
must later be freed to avoid a memory leak.
Any function taking a *TCReplica requires:
- the pointer must not be NUL;
- the pointer must be one previously returned from a tc_… function;
- the memory referenced by the pointer must never be modified by C code; and
- except for
tc_replica_free, ownership of a*TCReplicaremains with the caller.
Once passed to tc_replica_free, a *TCReplica becomes invalid and must not be used again.
TCReplicas are not threadsafe.
typedef struct TCReplica TCReplica;Trait Implementations