pub struct TCServer(/* private fields */);Expand description
***** TCServer *****
TCServer represents an interface to a sync server. Aside from new and free, a server
has no C-accessible API, but is designed to be passed to tc_replica_sync.
Safety
TCServer are not threadsafe, and must not be used with multiple replicas simultaneously.
typedef struct TCServer TCServer;Trait Implementations