tc_string_clone

Function tc_string_clone 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tc_string_clone( cstr: *const c_char, ) -> TCString
Create a new TCString by cloning the content of the given C string. The resulting TCString is independent of the given string, which can be freed or overwritten immediately.

EXTERN_C struct TCString tc_string_clone(const char *cstr);