tc_string_free

Function tc_string_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn tc_string_free(tcstring: *mut TCString)
Free a TCString. The given string must not be NULL. The string must not be used after this function returns, and must not be freed more than once.

EXTERN_C void tc_string_free(struct TCString *tcstring);