pub struct TCTaskList { /* private fields */ }Expand description
***** TCTaskList *****
TCTaskList represents a list of tasks.
The content of this struct must be treated as read-only: no fields or anything they reference should be modified directly by C code.
When an item is taken from this list, its pointer in items is set to NULL.
typedef struct TCTaskList {
// number of tasks in items
size_t len;
// reserved
size_t _u1;
// Array of pointers representing each task. These remain owned by the TCTaskList instance and
// will be freed by tc_task_list_free. This pointer is never NULL for a valid TCTaskList.
// Pointers in the array may be NULL after `tc_task_list_take`.
struct TCTask **items;
} TCTaskList;Auto Trait Implementations
impl !RefUnwindSafe for TCTaskList
impl !Send for TCTaskList
impl !Sync for TCTaskList
impl !UnwindSafe for TCTaskList
impl Freeze for TCTaskList
impl Unpin for TCTaskList
impl UnsafeUnpin for TCTaskList